Для 27 версии


# Расположение элементов


# Привязка данных к элементам форм
У каждого реквизита формы есть уникальный номер который указывается на элементе формы.

#copyinfo
0. 4
1. список реквизитов, первый элемент сама обраобтка, потом реквизиты
  0.  uuid реквизита
  1.  uuid реквизита
  2. 1??
  3.0. тип метаданных
  3.1. имя реквизита
2. список
